=begin
Copyright 2011 (c) TIG
All Rights Reserved.
THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED 
WARRANTIES,INCLUDING,WITHOUT LIMITATION,THE IMPLIED WARRANTIES OF 
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
###
Usage:
Menu "View" > "ImportCamera..."
Choose the file containing the camera data, in the following format:
name,xeye,yeye,zeye,xtarget,ytarget,ztarget,rollangle,fovangle
You can have one camera per line.
The xyz values should be in 'METERS'.
The two angles should be in degrees.
If the ",rollangle," is replaced with ",upx,upy,upz," a vector can be used.
New scene-tabs are made, each called 'name', with cameras as specified.
Edit the ICVSEP and ICDSEP constants below to suit your typical file's 
value-separator [' ',;:\t] and decimal.separator [. or ,]...
###
Donations:
info @ revitrev.org via PayPal.com
Version:
1.0 20110908 First issue.
1.1 20110910 METER version.
###
=end
require "sketchup.rb"

module TIG
    ### sort out values and decimal separators here...
    ICVSEP=' '### could be ' ', ',', '\t', ';', ':' etc
    ICDSEP=','### could be '.' or ','
    ###
def self.importcamera()
	fname=UI.openpanel("ImportCamera...",'','')
	return nil if fname==nil or fname=='' or not File.exist?(fname)
	model=Sketchup.active_model
	pages=model.pages
	view=model.active_view
	lines=IO.readlines(fname)
	lines.each{|data|
		data.chomp!
        line=data.split(ICVSEP)
		page_name=line[0]
        line.each{|lin|
          lin.strip!
          lin.tr!(ICDSEP,'.')
        }
		eye=[line[1].to_f.m, line[2].to_f.m, line[3].to_f.m]
		target=[line[4].to_f.m, line[5].to_f.m, line[6].to_f.m]
        vec=eye.vector_to(target)
        if line[9]###up is given as a vector
		  up=Geom::Vector3d.new(line[7].to_f.m, line[8].to_f.m, line[9].to_f.m)
          up=Y_AXIS if up.parallel?(vec)
          up=Z_AXIS if up.parallel?(vec)
          up=X_AXIS if up.parallel?(vec)
          fov=line[10].to_f  ### degrees
        else### up is calculated from an angle
          ang=line[7].to_f.degrees ### degrees>radians
          up=Z_AXIS.clone
          tr=Geom::Transformation.rotation(eye, vec, ang)
          up.transform!(tr)
          up=Y_AXIS if up.parallel?(vec)
          up=Z_AXIS if up.parallel?(vec)
          up=X_AXIS if up.parallel?(vec)
          fov=line[8].to_f ### degrees
        end
		cam=Sketchup::Camera.new(eye, target, up, true, fov)
		view.camera=cam
		new_page=pages.add(page_name)
	}
end#def

unless file_loaded?(File.basename(__FILE__))
	UI.menu("View").add_item("ImportCamera..."){TIG.importcamera()}
end
file_loaded(File.basename(__FILE__))

end#module
